==> 0.10.1.1.tar.gz: systemtraymenu/README.md <==
SystemTrayMenu<img src="https://raw.githubusercontent.com/Hofknecht/SystemTrayMenu/master/Resources/SystemTrayMenu.ico" alt="Trulli" width="24" height="24">  
------------------
[![Build Status](https://dev.azure.com/MarkusHofknecht/SystemTrayMenu/_apis/build/status/Hofknecht.SystemTrayMenu?branchName=master)](https://dev.azure.com/MarkusHofknecht/SystemTrayMenu/_build/latest?definitionId=2&branchName=master)

SystemTrayMenu is an improved open source toolbar for Windows.  
![1](https://user-images.githubusercontent.com/52528841/83351457-61139b80-a344-11ea-9b20-343ad372bb1b.gif)
![2](https://user-images.githubusercontent.com/52528841/83351459-640e8c00-a344-11ea-8735-164185090dcd.gif)
![3](https://user-images.githubusercontent.com/52528841/83351460-6670e600-a344-11ea-80e9-e707cf1a9dc0.gif)

Download the latest official version: http://hofknecht.eu/systemtraymenu/  
  

FAQ
------------------

**What do I have to do now as first steps?**  
  
SystemTrayMenu is portable so you do not have to install it.  
We would recommend to put the unzipped SystemTrayMenu folder into a folder like "Portable Tools" in the SystemTrayMenu root directory.  
  
1. After starting the application the first time you have to choose the root directory.  
C:\Cloudfolder e.g. Seafile, NextCloud or Dropbox\your folder with links e.g. Tools or SystemTrayMenu  
e.g. C:\Seafile\Tools  
In this directory you should put shortcuts of folders and files (App, Game, Script, URL, Network),  
which you are often using and especially when you can not find them over the windows start menu search.  
You can also consider to put there all files from your desktop.  

2. Move the SystemTrayMenu icon by drag and drop from the system tray into the taskbar below.  
![group icon out](https://user-images.githubusercontent.com/52528841/83349567-1ab74000-a336-11ea-8676-3db33615a57a.gif)

**How can I change the root directory?**

You can change the root directory in the settings menu, that you can open by right clicking on the SystemTrayMenu icon.  

**What does the hotkey do?**

In the settings menu you can choose a hotkey to open and close the SystemTrayMenu.  

**Can the SystemTrayMenu launch on windows startup?**

Yes, you can select this option in the settings menu, that you can open by right clicking on the SystemTrayMenu icon.  

**What can I do if I have a problem, idea or question?**

If a problem has occured or you have any ideas or questions, you are welcome to contact us.  
Our contact information you can find in the About window, that can be opened by right clicking on the SystemTrayMenu icon.   


Security
------------------

Some antiviruses might flag this program as malicious, but it is not! The source is open, so you can compile it yourself.  


Build
------------------

Install Visual Studio 2019.  

Contributing
------------------

If you would like to contribute, everyone is welcome to.  
If you are considering a feature, need guidance, or want to talk an idea out, don't hesitate to create an issue here.  
When contributing please respect the style used by the codebase and consider the following rules:  
*Run FixCop.  
*Increase version in assembly file.  
*Add a commit message like: IssueTitle (#xx), IssueTitle (#xx), version x.x.x.x .  
*Commit either directly to master or when you are not sure with your changes then create a branch https://guides.github.com/activities/hello-world/ .  
*Update issue and set the status to closed.

==> v0.10.2.5.tar.gz: systemtraymenu/README.md <==
SystemTrayMenu<img src="https://raw.githubusercontent.com/Hofknecht/SystemTrayMenu/master/Resources/SystemTrayMenu.ico" alt="Trulli" width="24" height="24">  
------------------
[![Build Status](https://dev.azure.com/MarkusHofknecht/SystemTrayMenu/_apis/build/status/Hofknecht.SystemTrayMenu?branchName=master)](https://dev.azure.com/MarkusHofknecht/SystemTrayMenu/_build/latest?definitionId=2&branchName=master)
[![All Releases](https://img.shields.io/github/downloads/Hofknecht/SystemTrayMenu/total.svg)](https://github.com/Hofknecht/SystemTrayMenu/releases)

SystemTrayMenu is an improved open source toolbar for Windows.  
![1](https://user-images.githubusercontent.com/52528841/83351457-61139b80-a344-11ea-9b20-343ad372bb1b.gif)
![2](https://user-images.githubusercontent.com/52528841/83351459-640e8c00-a344-11ea-8735-164185090dcd.gif)
![3](https://user-images.githubusercontent.com/52528841/83351460-6670e600-a344-11ea-80e9-e707cf1a9dc0.gif)

Download the latest official version:  
https://github.com/Hofknecht/SystemTrayMenu/releases/latest/download/SystemTrayMenu.zip
  

FAQ
------------------

**What do I have to do now as first steps?**  
  
SystemTrayMenu is portable so you do not have to install it.  
We would recommend to put the unzipped SystemTrayMenu folder into a folder like "Portable Tools" in the SystemTrayMenu root directory.  
  
1. After starting the application the first time you have to choose the root directory.  
C:\Cloudfolder e.g. Seafile, NextCloud or Dropbox\your folder with links e.g. Tools or SystemTrayMenu  
e.g. C:\Seafile\Tools  
In this directory you should put shortcuts of folders and files (App, Game, Script, URL, Network),  
which you are often using and especially when you can not find them over the windows start menu search.  
You can also consider to put there all files from your desktop.  

2. Move the SystemTrayMenu icon by drag and drop from the system tray into the taskbar below.  
![group icon out](https://user-images.githubusercontent.com/52528841/83349567-1ab74000-a336-11ea-8676-3db33615a57a.gif)

**How can I change the root directory?**

You can change the root directory in the settings menu, that you can open by right clicking on the SystemTrayMenu icon.  

**What does the hotkey do?**

In the settings menu you can choose a hotkey to open and close the SystemTrayMenu.  

**Can the SystemTrayMenu launch on windows startup?**

Yes, you can select this option in the settings menu, that you can open by right clicking on the SystemTrayMenu icon.  

**What can I do if I have a problem, idea or question?**

If a problem has occured or you have any ideas or questions, you are welcome to contact us.  
Our contact information you can find in the About window, that can be opened by right clicking on the SystemTrayMenu icon.   


Security
------------------

Some antiviruses might flag this program as malicious, but it is not! The source is open, so you can compile it yourself.  


Build
------------------

Install Visual Studio 2019.  
Install netcoreapp3.1 [https://dotnet.microsoft.com](https://dotnet.microsoft.com/download/dotnet-core/thank-you/sdk-3.1.300-windows-x64-installer)

Contributing
------------------

If you would like to contribute, everyone is welcome to.  
If you are considering a feature, need guidance, or want to talk an idea out, don't hesitate to create an issue here.  
When contributing please respect the style used by the codebase and consider the following rules:  
*Run FixCop.  
*Increase version in assembly file.  
*Add a commit message like: IssueTitle (#xx), IssueTitle (#xx), version x.x.x.x .  
*Commit either directly to master or when you are not sure with your changes then create a branch https://guides.github.com/activities/hello-world/ .  
*Update issue and set the status to closed.  

Donations
------------------

Don't hesitate to donate if you appreciate SystemTrayMenu and would like to support our work. 
[https://www.paypal.com](https://www.paypal.com/myaccount/transfer/homepage/preview) `Tanja.Kauth@gmx.de`
